function chart_pos_order (widget) {
    "use strict";

    var model = openerp;

    widget.ChartPosOrderWidget = widget.Base.extend({
        template: 'ChartPosOrder',
        data: [],
        events: {
            'click .month': 'showMonth',
            'click .week': 'showWeek',
        },

        init: function (parent) {
            this._super(parent, {
                width: 6,
                height: 4
            });
        },

        start: function () {
            var self = this;
            self.fetchInitial();
        },

        fetchInitial:function() {
            var self = this;
            self.$el.block({
                message: null,
                overlayCSS: {
                    backgroundColor: '#FAFAFA'
                }
            });

            self.$el.find('.widget-content.widget-loading').css('display','flex');

            self.fecthPosOrder().then(function (PosOrder) {
                return PosOrder;
            }).then(function (PosOrder) {
                self.PosOrder = PosOrder;
                return self.showWeek();
            });
        },
        
        fecthPosOrder: function() {
            var self = this;
            var defer = $.Deferred();
            var fields = ['id','name','date_order','amount_total'];
            var domain = [['state','in',['paid','done','invoiced']]];
            var PosOrder = new model.web.Model('pos.order');
            PosOrder.query(fields).filter(domain).all().then(function (results) {
                defer.resolve(results);
            });

            return defer;
        },

        getMonthPosOrder:function(mes) {
            var self = this;
            if (mes < 10){
                var fecha = moment().format('YYYY')+'-'+'0'+mes;    
            }else{
                var fecha = moment().format('YYYY')+'-'+mes;    
            }
            return _.flatten(_.filter(self.PosOrder,function (inv) {
                return moment(inv.date_order).format('YYYY-MM') === fecha;
            }));
        },

        getWeekPosOrder:function(day) {
            var self = this;
            var week = moment().week();
            return _.flatten(_.filter(self.PosOrder,function (inv) {
                return moment(inv.date_order).week() === week & moment(inv.date_order).isoWeekday() === day;
            }));
        },
        
        showMonth: function() {
            var self = this;
            var order;
            var mes = 0;
            var data = [];
            
            for (var i = 1; i <= 12; i++) {
                order = self.getMonthPosOrder(i);
                var total = _.reduce(_.map(order,function(item) {
                    return item.amount_total;
                }),function(memo, num) {
                    return memo + num;
                },0);
                data.push({
                    amount_total: accounting.formatNumber(total,0,".",","),
                })
            }
            self.$el.unblock();
            self.$el.find('.widget-content.widget-loading').css('display','none');
            self.fetchMonthChart(data);
        },

        showWeek: function (){
            var self = this;
            var order;
            var data = [];
            for (var i = 1; i <= 7; i++) {
                order = self.getWeekPosOrder(i);
                var total = _.reduce(_.map(order,function(item) {
                    return item.amount_total;
                }),function(memo, num) {
                    return memo + num;
                },0);
                data.push({
                    amount_total: accounting.formatNumber(total,0,".",","),
                });
            }
            self.$el.unblock();
            self.$el.find('.widget-content.widget-loading').css('display','none');
            self.fetchWeekChart(data);
        },

        fetchMonthChart: function (data) {
            var self = this;
            var label = ['Enero', 'Febrero', 'Marzo','Abril','Mayo','Junio','Julio','Agosto','Septiembre','Octubre','Noviembre','Diciembre'];
            var body = [];
            var item;
            var rank = 12;

            if (data.length < rank && data.length > 0){
                rank= ranking.length;
            }
            for (var i = 0; i < rank; i++) {
                if (data[i]) {
                    item = data[i];
                }
                if (data.length === 0) {
                    item = {};
                    item.amount_total = 0;
                }
                body.push(item.amount_total);
            }

            // Global method for setting Y axis number format.
            Chart.scaleService.updateScaleDefaults('linear', {
              ticks: {
                callback: function(tick) {
                    return tick.toLocaleString('de-DE');
                }
              }
            });
            Chart.defaults.global.tooltips.callbacks.label = function(tooltipItem, data) {
                var dataset = data.datasets[tooltipItem.datasetIndex];
                var datasetLabel = dataset.label || '';
                return datasetLabel +  dataset.data[tooltipItem.index].toLocaleString('de-DE');
            };
            var chart = new Chart(this.$el.find(".widget-content").find('canvas'), {
                type: 'line',
                data: {
                    labels: label,
                    datasets: [
                        {
                            label: false,
                            data: body,
                            backgroundColor: '#e3f2fd',
                            borderColor: '#64b5f6',
                            borderWidth: 2,
                            fill: true,
                        }
                    ]
                },
                options: {
                    responsive: true,
                    title: {
                        display: false,
                    },
                    hover: {
                        mode: 'nearest',
                        intersect: true
                    },
                    legend: {
                       display: false,
                    },
                    layout: {
                        padding: {
                            top: 35,
                            bottom: 0,
                            left : 0,
                            rigth: 0,
                        }
                    },
                }
            });
        },

        fetchWeekChart: function (data) {
            var self = this;
            var label = ['Lunes', 'Martes', 'Miercoles','Jueves','Viernes','Sabado','Domingo'];
            var body = [];
            var item;
            var rank = 7;

            if (data.length < rank && data.length > 0){
                rank= ranking.length;
            }
            for (var i = 0; i < rank; i++) {
                if (data[i]) {
                    item = data[i];
                }
                if (data.length === 0) {
                    item = {};
                    item.amount_total = 0;
                }
                body.push(item.amount_total);
            }

            // Global method for setting Y axis number format.
            Chart.scaleService.updateScaleDefaults('linear', {
              ticks: {
                callback: function(tick) {
                    return tick.toLocaleString('de-DE');
                }
              }
            });
            Chart.defaults.global.tooltips.callbacks.label = function(tooltipItem, data) {
                var dataset = data.datasets[tooltipItem.datasetIndex];
                var datasetLabel = dataset.label || '';
                return datasetLabel +  dataset.data[tooltipItem.index].toLocaleString('de-DE');
            };
            var chart = new Chart(this.$el.find(".widget-content").find('canvas'), {
                type: 'line',
                data: {
                    labels: label,
                    datasets: [
                        {
                            label: false,
                            data: body,
                            backgroundColor: '#e3f2fd',
                            borderColor: '#64b5f6',
                            borderWidth: 2,
                            fill: true,
                        }
                    ]
                },
                options: {
                    responsive: true,
                    title: {
                        display: false,
                    },
                    hover: {
                        mode: 'nearest',
                        intersect: true
                    },
                    legend: {
                       display: false,
                    },
                    layout: {
                        padding: {
                            top: 35,
                            bottom: 15,
                            left : 0,
                            rigth: 0,
                        }
                    },
                }
            });
        },

    });
}
